Learn R Programming

npRmpi (version 0.60-20)

mpi.cart.rank: MPI_Cart_rank

Description

mpi.cart.rank translates a Cartesian topology coordinate to its rank.

Usage

mpi.cart.rank(comm=3, coords)

Value

mpi.cart.rank returns the rank of the specified process.

Arguments

comm

Communicator with Cartesian structure

coords

Specifies the Cartesian coordinates of a process

Author

Alek Hunchak and Hao Yu

Details

For a process group with a Cartesian topology, this function translates the logical process coordinates to process ranks as they are used by the point-to-point routines. It is the inverse map of mpi.cart.coords.

References

https://www.mpich.org/, https://www.mpich.org/static/docs/latest/www3/

See Also

mpi.cart.coords

Examples

Run this code
if (FALSE) {
# Not run in checks: requires a Cartesian communicator built from spawned slaves.
#Need at least 9 slaves
mpi.bcast.cmd(mpi.cart.create(1,c(3,3),c(F,T)))
mpi.cart.create(1,c(3,3),c(F,T))
mpi.cart.rank(3,c(1,0))
}

Run the code above in your browser using DataLab