Learn R Programming

npRmpi (version 0.60-20)

mpi.get.sourcetag: Utility for finding the source and tag of a received message

Description

mpi.get.sourcetag finds the source and tag of a received message.

Usage

mpi.get.sourcetag(status = 0)

Value

2 dim int vector. The first integer is the source and the second is the tag.

Arguments

status

a status number

Author

Hao Yu

Details

When mpi.any.source and/or mpi.any.tag are used by mpi.recv or mpi.probe, one can use mpi.get.sourcetag to find who sends the message or with what tag number. mpi.get.sourcetag must be called immediately after calling mpi.recv or mpi.probe otherwise the obtained information may not be right.

References

https://www.mpich.org/, https://www.mpich.org/static/docs/latest/www3/

See Also

mpi.send, mpi.recv, mpi.probe, mpi.get.count