Learn R Programming

npRmpi (version 0.60-20)

mpi.realloc: Find and increase the lengths of MPI opaques comm, request, and status

Description

mpi.comm.maxsize, mpi.request.maxsize, and mpi.status.maxsize find the lengths of comm, request, and status arrays respectively.

mpi.realloc.comm, mpi.realloc.request and mpi.realloc.status increase the lengths of comm, request and status arrays to newmaxsize respectively if newmaxsize is bigger than the original maximum size.

Usage

mpi.realloc.comm(newmaxsize)
mpi.realloc.request(newmaxsize)
mpi.realloc.status(newmaxsize)
mpi.comm.maxsize()
mpi.request.maxsize()
mpi.status.maxsize()

Value

  • mpi.realloc.comm, mpi.realloc.request, mpi.realloc.status: no return value (called for side effects).

  • mpi.comm.maxsize, mpi.request.maxsize, mpi.status.maxsize: integer size limits.

Arguments

newmaxsize

an integer.

Author

Hao Yu

Details

When Rmpi is loaded, Rmpi allocs comm array with size 10, request array with 10,000 and status array with 5,000. They should be enough in most cases. They use less than 150KB system memory. In rare case, one can use mpi.realloc.comm, mpi.realloc.request and mpi.realloc.status to increase them to bigger arrays.

References

https://www.mpich.org/, https://www.mpich.org/static/docs/latest/www3/