Learn R Programming

npRmpi (version 0.60-20)

np.mpi.initialize: Initialize Master and Slave Nodes for the np Package

Description

np.mpi.initialize is used to initialize master and slave nodes.

Usage

np.mpi.initialize()

Arguments

Value

np.mpi.initialize returns no value for the sender and an expression of the transmitted command for others.

Author

Jeffrey S. Racine racinej@mcmaster.ca