mpi.get.sourcetag finds the source and tag of a received message.
mpi.get.sourcetag(status = 0)2 dim int vector. The first integer is the source and the second is the tag.
a status number
Hao Yu
When mpi.any.source and/or mpi.any.tag are
used by mpi.recv or mpi.probe, one can use
mpi.get.sourcetag
to find who sends the message or with what tag number.
mpi.get.sourcetag must be called immediately after calling
mpi.recv or mpi.probe otherwise the obtained information may not
be right.
https://www.mpich.org/, https://www.mpich.org/static/docs/latest/www3/
mpi.send, mpi.recv, mpi.probe,
mpi.get.count