mpi.comm.maxsize, mpi.request.maxsize, and
mpi.status.maxsize find the lengths of comm, request, and status
arrays respectively.
mpi.realloc.comm, mpi.realloc.request and
mpi.realloc.status increase the lengths of comm, request and
status arrays to newmaxsize respectively if newmaxsize is
bigger than the original maximum size.
mpi.realloc.comm(newmaxsize)
mpi.realloc.request(newmaxsize)
mpi.realloc.status(newmaxsize)
mpi.comm.maxsize()
mpi.request.maxsize()
mpi.status.maxsize()mpi.realloc.comm, mpi.realloc.request, mpi.realloc.status:
no return value (called for side effects).
mpi.comm.maxsize, mpi.request.maxsize, mpi.status.maxsize:
integer size limits.
an integer.
Hao Yu
When Rmpi is loaded, Rmpi allocs comm array with size 10, request
array with 10,000 and status array with 5,000. They should be enough in
most cases. They use less than 150KB system memory. In rare case, one can
use mpi.realloc.comm, mpi.realloc.request and
mpi.realloc.status to increase them to bigger arrays.
https://www.mpich.org/, https://www.mpich.org/static/docs/latest/www3/