powered by
np.mpi.initialize is used to initialize master and slave nodes.
np.mpi.initialize
np.mpi.initialize()
np.mpi.initialize returns no value for the sender and an expression of the transmitted command for others.
Jeffrey S. Racine racinej@mcmaster.ca